models
*******


DualAttentionModel
==================
.. autoclass:: ai4water.tf_models.DualAttentionModel
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

TemporalFusionTransformer
=========================
.. autoclass:: ai4water.models.tensorflow.TemporalFusionTransformer
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

NBeats
======
.. autoclass:: ai4water.models.tensorflow.NBeats
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

HARHNModel
==========
.. autoclass:: ai4water.pytorch_models.HARHNModel
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

IMVModel
========
.. autoclass:: ai4water.pytorch_models.IMVModel
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
